Module process

Module process 

Structs

Process

Type Aliases

BlockingCallback
ExitedCallback
Type for the callback that is called when a process exits. Arguments are the process manager, the process key, the error code to return, and a bool indicating if the process is going to be restarted.
ReturnFuture
StartedCallback
StringCallback