Process

Struct Process 

pub struct Process { /* private fields */ }

Implementations

Source

impl Process

pub fn new() -> Self

pub fn with_executable(self, executable: impl ToString) -> Self

Sets the executable to run.

pub fn with_args(self, args: impl IntoIterator<Item = impl ToString>) -> Self

Sets the arguments to pass to the executable.

pub fn with_cancel_timeout(self, t: impl Into<Option<Duration>>) -> Self

Sets the cancellation timeout before forcing the process to exit.

pub fn with_env( self, env: impl IntoIterator<Item = (impl ToString, impl ToString)>, ) -> Self

Sets the environment variables to pass to the executable.

pub fn with_on_stdout<F, A>(self, on_stdout: F) -> Self
where F: Fn(ProcessManager, ProcessKey, String) -> A + Unpin + Send + Sync + 'static, A: Future<Output = ()> + Send + 'static,

Sets the callback to run when the process writes to stdout.

pub fn with_on_stderr<F, A>(self, on_stderr: F) -> Self
where F: Fn(ProcessManager, ProcessKey, String) -> A + Unpin + Send + Sync + 'static, A: Future<Output = ()> + Send + 'static,

Sets the callback to run when the process writes to stderr.

pub fn with_fds<F>(self, fds: F) -> Self
where F: FnOnce() -> Vec<OwnedFd> + Send + Sync + 'static,

Shares Fds with the child process Closure produces a vector of Fd to share with the child process

pub fn with_on_start<F, A>(self, on_start: F) -> Self
where F: Fn(ProcessManager, ProcessKey, bool) -> A + Unpin + Send + Sync + 'static, A: Future<Output = ()> + Send + 'static,

This is called when the process is started.

It passes a single argument: a bool indicating whether the process was restarted or if it was started for the first time.

pub fn with_on_exit<F, A>(self, on_exit: F) -> Self
where F: Fn(ProcessManager, ProcessKey, Option<i32>, bool) -> A + Unpin + Send + Sync + 'static, A: Future<Output = ()> + Send + 'static,

Sets the callback to run when the process exits. This is called after the process exits, or before it restarts.

It passes two arguments: an optional exit code, and a bool indicating whether the process is going to be restarted or not.