ExitedCallback

Type Alias ExitedCallback 

pub type ExitedCallback = Box<dyn Fn(ProcessManager, ProcessKey, Option<i32>, bool) -> ReturnFuture + Send + Sync + 'static>;
Type for the callback that is called when a process exits. Arguments are the process manager, the process key, the error code to return, and a bool indicating if the process is going to be restarted.

Aliased Type

pub struct ExitedCallback(/* private fields */);