pub struct ProcessKey(/* private fields */);Trait Implementations
Sourceimpl Clone for ProcessKey
impl Clone for ProcessKey
Sourcefn clone(&self) -> ProcessKey
fn clone(&self) -> ProcessKey
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProcessKey
impl Debug for ProcessKey
Sourceimpl Default for ProcessKey
impl Default for ProcessKey
Sourcefn default() -> ProcessKey
fn default() -> ProcessKey
Returns the “default value” for a type. Read more
Sourceimpl From<KeyData> for ProcessKey
impl From<KeyData> for ProcessKey
Sourceimpl Hash for ProcessKey
impl Hash for ProcessKey
Sourceimpl Key for ProcessKey
impl Key for ProcessKey
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for ProcessKey
impl Ord for ProcessKey
Sourcefn cmp(&self, other: &ProcessKey) -> Ordering
fn cmp(&self, other: &ProcessKey) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ProcessKey
impl PartialEq for ProcessKey
Sourceimpl PartialOrd for ProcessKey
impl PartialOrd for ProcessKey
impl Copy for ProcessKey
impl Eq for ProcessKey
impl StructuralPartialEq for ProcessKey