Structs
Type Aliases
- Blocking
Callback - Exited
Callback - Type for the callback that is called when a process exits. Arguments are the process manager, the process key, the error code to return, and a bool indicating if the process is going to be restarted.
- Return
Future - Started
Callback - String
Callback